@@ -174,9 +174,9 @@ void Component::mousePressEvent( QGraphicsSceneMouseEvent* event )
         if( m_selecComp )
         {
             m_selecComp->compSelected( this );
-            return;
+            //return;
         }
-        if( event->modifiers() == Qt::ControlModifier ) setSelected( !isSelected() );
+        else if( event->modifiers() == Qt::ControlModifier ) setSelected( !isSelected() );
         else{
             QList<QGraphicsItem*> itemlist = Circuit::self()->selectedItems();
             if( !isSelected() )     // Unselect everything and select this
@@ -319,10 +319,10 @@ void Component::contextMenu( QGraphicsSceneContextMenuEvent* event, QMenu* menu
 {
     if( !event && m_isMainComp ) // Main Component in Subcircuit
     {
-        /*QAction* propertiesAction = menu->addAction( QIcon( ":/properties.svg"),tr("Properties") );
+        QAction* propertiesAction = menu->addAction( QIcon( ":/properties.svg"),tr("Properties") );
         connect( propertiesAction, &QAction::triggered,
                              this, &Component::slotProperties, Qt::UniqueConnection );
-        menu->addSeparator();*/
+        menu->addSeparator();
         return;
     }
     m_eventpoint = mapToScene( toGrid(event->pos()) );
@@ -555,7 +555,7 @@ void Component::remSignalPin( Pin* pin )
     m_signalPin.removeAll( pin );
 }
 
-void Component::setHidden(bool hid, bool hidArea, bool hidLabel )
+void Component::setHidden( bool hid, bool hidArea, bool hidLabel )
 {
     m_hidden = hid;
 
@@ -563,10 +563,12 @@ void Component::setHidden(bool hid, bool hidArea, bool hidLabel )
     else this->setVisible( !hid );
 
     if( hidLabel ){
-        setShowId( false );
-
+        m_valLabel->setVisible( false );
+        m_idLabel->setVisible( false );
+    }else{
+        m_valLabel->setVisible( m_showVal );
+        m_idLabel->setVisible( m_showId );
     }
-    m_valLabel->setVisible( !hidLabel ); //setShowProp("");
 }
 
 /*QString Component::print()
