@@ -47,11 +47,11 @@ SwitchDip::SwitchDip( QObject* parent, QString type, QString id )
     Simulator::self()->addToUpdateList( this );
 
     addPropGroup( { tr("Main"), {
-new IntProp<SwitchDip>( "Size", tr("Size"),tr("_Switches"), this, &SwitchDip::size, &SwitchDip::setSize, "uint" )
-    }} );
+new IntProp<SwitchDip>("Size", tr("Size"),tr("_Switches"), this, &SwitchDip::size, &SwitchDip::setSize,0,"uint" )
+    }, groupNoCopy} );
     addPropGroup( {"Hidden", {
-new IntProp<SwitchDip>( "State", "","", this, &SwitchDip::state, &SwitchDip::setState, "uint" )
-    }} );
+new IntProp<SwitchDip>("State", "","", this, &SwitchDip::state, &SwitchDip::setState,0,"uint" )
+    }, groupHidden} );
 }
 SwitchDip::~SwitchDip(){}
 
