@@ -8,24 +8,42 @@
 
 #include <QWidget>
 
-class QDial;
+class QAbstractSlider;
 class QVBoxLayout;
+class CustomDial;
+class CustomSlider;
 
 class DialWidget : public QWidget
 {
     Q_OBJECT
     
     public:
-        DialWidget();
+        DialWidget( QWidget* parent=NULL );
         ~DialWidget();
 
-        void setupWidget();
+        double scale() { return m_scale; }
+        void setScale( double s );
 
-        QDial* dial;
-        QVBoxLayout* verticalLayout;
+        void setSize( int size );
 
-    private:
+        void setType( int type );
+
+        void setValue( int v );
+        int value();
+
+        QAbstractSlider* dial() { return m_dial; }
+
+    protected:
         virtual void paintEvent( QPaintEvent* e) override;
+
+        int m_size;
+        double m_scale;
+
+        QVBoxLayout* m_verticalLayout;
+
+        QAbstractSlider* m_dial;
+        CustomDial*      m_knob;
+        CustomSlider*    m_slider;
 };
 #endif
 
